@@ -9,15 +9,10 @@ def get_authorization_scheme_param(authorization_header_value: str) -> Tuple[str
 
 
 class OAuth2PasswordBearer:
-    def __init__(self, auto_error: bool = True):
-        self.auto_error = auto_error
 
     async def __call__(self, request) -> Optional[str]:
-        authorization: str = request.headers.get("Authorization")
+        authorization: str = request.headers.get("Authorization") or request.headers.get("authorization")
         scheme, param = get_authorization_scheme_param(authorization)
         if not authorization or scheme.lower() != "bearer":
-            if self.auto_error:
-                raise Exception("Could not validate credentials")
-            else:
-                return None
+            raise Exception("Could not validate credentials")
         return param
